function w=moltomas(x,mw)
% moltomas	- Converts mole fractions to mass fractions
% function w=moltomas(x,mw)
% Argument List:
% Argument   Gives
%    x     the mol fractions of the compounds in a stream
%    mw    the molecular weights of the compounds
% w returns the mass fractions of the compounds
if length(x)==length(mw)
   mas=x.*mw;
   tot=sum(mas);
   w=mas/tot;
else
   disp('The lengths of your arguments are not the same!')
end
